# Changelog

## 0.1.1 (2021-11-02)

* Update documentation

### Dev

* Move CI from TravisCI to Github Actions
* Switch to Poetry

## 0.1.0 (2019-08-06)

* Add specification basics.
* Add error reporting.
